==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/billing/v20180709/models/DescribeDosageCosDetailByDateRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.billing.v20180709.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDosageCosDetailByDateRequest extends AbstractModel{

    /**
    * 查询用量开始时间
    */
    @SerializedName("StartDate")
    @Expose
    private String StartDate;

    /**
    * 查询用量结束时间（与开始时间同月，不支持跨月查询）
    */
    @SerializedName("EndDate")
    @Expose
    private String EndDate;

    /**
    * COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291
    */
    @SerializedName("BucketName")
    @Expose
    private String BucketName;

    /**
     * Get 查询用量开始时间 
     * @return StartDate 查询用量开始时间
     */
    public String getStartDate() {
        return this.StartDate;
    }

    /**
     * Set 查询用量开始时间
     * @param StartDate 查询用量开始时间
     */
    public void setStartDate(String StartDate) {
        this.StartDate = StartDate;
    }

    /**
     * Get 查询用量结束时间（与开始时间同月，不支持跨月查询） 
     * @return EndDate 查询用量结束时间（与开始时间同月，不支持跨月查询）
     */
    public String getEndDate() {
        return this.EndDate;
    }

    /**
     * Set 查询用量结束时间（与开始时间同月，不支持跨月查询）
     * @param EndDate 查询用量结束时间（与开始时间同月，不支持跨月查询）
     */
    public void setEndDate(String EndDate) {
        this.EndDate = EndDate;
    }

    /**
     * Get COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291 
     * @return BucketName COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291
     */
    public String getBucketName() {
        return this.BucketName;
    }

    /**
     * Set COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291
     * @param BucketName COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291
     */
    public void setBucketName(String BucketName) {
        this.BucketName = BucketName;
    }

    public DescribeDosageCosDetailByDateRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeDosageCosDetailByDateRequest(DescribeDosageCosDetailByDateRequest source) {
        if (source.StartDate != null) {
            this.StartDate = new String(source.StartDate);
        }
        if (source.EndDate != null) {
            this.EndDate = new String(source.EndDate);
        }
        if (source.BucketName != null) {
            this.BucketName = new String(source.BucketName);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "StartDate", this.StartDate);
        this.setParamSimple(map, prefix + "EndDate", this.EndDate);
        this.setParamSimple(map, prefix + "BucketName", this.BucketName);

    }
}

==> tencentcloud-sdk-java-3.1.708-sources.jar: com/tencentcloudapi/billing/v20180709/models/DescribeDosageCosDetailByDateRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.billing.v20180709.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDosageCosDetailByDateRequest extends AbstractModel{

    /**
    * 查询用量开始时间，例如：2020-09-01
    */
    @SerializedName("StartDate")
    @Expose
    private String StartDate;

    /**
    * 查询用量结束时间，例如：2020-09-30（与开始时间同月，不支持跨月查询）
    */
    @SerializedName("EndDate")
    @Expose
    private String EndDate;

    /**
    * COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291
    */
    @SerializedName("BucketName")
    @Expose
    private String BucketName;

    /**
     * Get 查询用量开始时间，例如：2020-09-01 
     * @return StartDate 查询用量开始时间，例如：2020-09-01
     */
    public String getStartDate() {
        return this.StartDate;
    }

    /**
     * Set 查询用量开始时间，例如：2020-09-01
     * @param StartDate 查询用量开始时间，例如：2020-09-01
     */
    public void setStartDate(String StartDate) {
        this.StartDate = StartDate;
    }

    /**
     * Get 查询用量结束时间，例如：2020-09-30（与开始时间同月，不支持跨月查询） 
     * @return EndDate 查询用量结束时间，例如：2020-09-30（与开始时间同月，不支持跨月查询）
     */
    public String getEndDate() {
        return this.EndDate;
    }

    /**
     * Set 查询用量结束时间，例如：2020-09-30（与开始时间同月，不支持跨月查询）
     * @param EndDate 查询用量结束时间，例如：2020-09-30（与开始时间同月，不支持跨月查询）
     */
    public void setEndDate(String EndDate) {
        this.EndDate = EndDate;
    }

    /**
     * Get COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291 
     * @return BucketName COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291
     */
    public String getBucketName() {
        return this.BucketName;
    }

    /**
     * Set COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291
     * @param BucketName COS 存储桶名称，可通过Get Service 接口是用来获取请求者名下的所有存储空间列表（Bucket list）https://cloud.tencent.com/document/product/436/8291
     */
    public void setBucketName(String BucketName) {
        this.BucketName = BucketName;
    }

    public DescribeDosageCosDetailByDateRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeDosageCosDetailByDateRequest(DescribeDosageCosDetailByDateRequest source) {
        if (source.StartDate != null) {
            this.StartDate = new String(source.StartDate);
        }
        if (source.EndDate != null) {
            this.EndDate = new String(source.EndDate);
        }
        if (source.BucketName != null) {
            this.BucketName = new String(source.BucketName);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "StartDate", this.StartDate);
        this.setParamSimple(map, prefix + "EndDate", this.EndDate);
        this.setParamSimple(map, prefix + "BucketName", this.BucketName);

    }
}
